==> haskell-microlens-platform-0.3.9.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-platform
version: 0.3.9.0
id: microlens-platform-0.3.9.0-DZypXjVRviH9gIqWPMsMFD
key: microlens-platform-0.3.9.0-DZypXjVRviH9gIqWPMsMFD
license: BSD3
maintainer: Artyom <yom@artyom.me>
homepage: http://github.com/aelve/microlens
synopsis: Feature-complete microlens
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.
    .
    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/aelve/microlens#readme on Github>.
category: Data, Lenses
author: Edward Kmett, Artyom
exposed: True
exposed-modules:
    Lens.Micro.Platform Lens.Micro.Platform.Internal
abi: 219432e685a3715b9633c40cede65949
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/microlens-platform-0.3.9.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/microlens-platform-0.3.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/microlens-platform-0.3.9.0
hs-libraries: HSmicrolens-platform-0.3.9.0-DZypXjVRviH9gIqWPMsMFD
depends:
    base-4.9.1.0 hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    microlens-0.4.8.0-5PXN9DedWooJg6UJ24ter0
    microlens-ghc-0.4.8.0-Ievlk22npCk69ALZCC0Cgz
    microlens-mtl-0.1.11.0-JZGlAY1k7Eo2CcDKB6BH2V
    microlens-th-0.4.1.1-DS5mBQOVXPfALmfN2UZZ6b
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock
haddock-html: /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-platform-0.3.9.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-platform
version: 0.3.9.0
id: microlens-platform-0.3.9.0-8er0t4SpK5G71aV3mVKPya
key: microlens-platform-0.3.9.0-8er0t4SpK5G71aV3mVKPya
license: BSD3
maintainer: Artyom <yom@artyom.me>
homepage: http://github.com/aelve/microlens
synopsis: Feature-complete microlens
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.
    .
    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/aelve/microlens#readme on Github>.
category: Data, Lenses
author: Edward Kmett, Artyom
exposed: True
exposed-modules:
    Lens.Micro.Platform Lens.Micro.Platform.Internal
abi: 3074153e226b7acd822c6fca44f3b3d6
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/microlens-platform-0.3.9.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/microlens-platform-0.3.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/microlens-platform-0.3.9.0
hs-libraries: HSmicrolens-platform-0.3.9.0-8er0t4SpK5G71aV3mVKPya
depends:
    base-4.9.1.0 hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    microlens-0.4.8.1-BVhsezHoPw9Ez18LAXVtpM
    microlens-ghc-0.4.8.0-5qd8myS6x2Z3CN7myyWRzG
    microlens-mtl-0.1.11.0-9MGmPSS1MMRHOvHzdJaq9s
    microlens-th-0.4.1.1-5szUVILkeNp4QYbk6VKas3
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock
haddock-html: /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
